Learn R Programming

simulariatools (version 2.5.1)

createBaseMap: Create base map (OBSOLETE)

Description

Create base map. This is meant to be the deepest layer of contour plot map. Axes coordinates are supposed to be in meters.

Usage

createBaseMap(
  imageFile,
  domain = c(0, 0, 1000, 1000, 5, 5),
  font_size = 10,
  font_family = "sans"
)

Value

A ggplot2 plot.

Arguments

imageFile

(string) Path to the background 'png' file.

domain

Six components vector with the domain SW corner coordinates, the X and Y extensions, and the number of breaks along the to axis (X, Y, DX, DY, NX, NY)

font_size

This is the font size for axis labels

font_family

This is the font family for labels

Examples

Run this code
if (FALSE) {
# Import image 'img'. Divide the axis with 9 ticks.
v <- createBaseMap(img, c(minx, miny, extent, extent, 9, 9), font_size=10)
}

Run the code above in your browser using DataLab