Learn R Programming

simulariatools (version 2.5.1)

plotAvgRad: Plot hourly average radiation

Description

Plot a histogram with hourly average of solar radiation, together with hourly maxima for June and December.

Usage

plotAvgRad(mydata, date = "date", rad = "radg")

Value

A ggplot2 plot.

Arguments

mydata

A data frame containing fields with solar radiation time series.

date

Name of the column representing date and time.

rad

Name of the column representing radiation.

See Also

plotStabilityClass(), plotAvgTemp()

Examples

Run this code
data(stMeteo)
plotAvgRad(stMeteo, date = "date", rad = "radg")

Run the code above in your browser using DataLab