Learn R Programming

simulariatools (version 2.5.1)

plotStabilityClass: Plot stability class

Description

Plot histogram of stability class on season or hour base.

Usage

plotStabilityClass(mydata, sc = "sc", type = "season")

Value

A ggplot2 plot.

Arguments

mydata

A data frame containing date and stability class fields.

sc

The name of the stability class field.

type

type determines how the data are split and then plotted. Accepted values are "season" (default) and "hour".

Details

Numerical values of stability classes are mapped as: 1 = A, 2 = B, ..., 6 = F.

See Also

stabilityClass(), plotAvgRad(), plotAvgTemp()

Examples

Run this code
data(stMeteo)

# Season plot of stability class pgt
plotStabilityClass(stMeteo, sc = "pgt", type = "season")

# Hourly plot of stability class pgt
plotStabilityClass(stMeteo, sc = "pgt", type = "hour")

Run the code above in your browser using DataLab