Learn R Programming

simulariatools (version 2.5.1)

rollingMax: Compute rolling max

Description

The rolling maximum value along a series of data is computed.

Usage

rollingMax(mydata, length = 24)

Value

A numeric vector of the same length as mydata.

Arguments

mydata

A vector of data

length

The length of data subset where the maximum values has to be picked. The value must be greater or equal than 3.

Details

It computes the maximum value centred along a subset of data.

Examples

Run this code
# Compute rolling max along 24 hours on hourly time series
data(airquality)
solar.R.24 <- rollingMax(mydata = airquality$Solar.R, length = 24)

Run the code above in your browser using DataLab