powered by
Plot a histogram with hourly average of solar radiation, together with hourly maxima for June and December.
plotAvgRad(mydata, date = "date", rad = "radg")
A ggplot2 plot.
ggplot2
A data frame containing fields with solar radiation time series.
Name of the column representing date and time.
Name of the column representing radiation.
plotStabilityClass(), plotAvgTemp()
plotStabilityClass()
plotAvgTemp()
data(stMeteo) plotAvgRad(stMeteo, date = "date", rad = "radg")
Run the code above in your browser using DataLab