powered by
The rolling maximum value along a series of data is computed.
rollingMax(mydata, length = 24)
A numeric vector of the same length as mydata.
mydata
A vector of data
The length of data subset where the maximum values has to be picked. The value must be greater or equal than 3.
It computes the maximum value centred along a subset of data.
# Compute rolling max along 24 hours on hourly time series data(airquality) solar.R.24 <- rollingMax(mydata = airquality$Solar.R, length = 24)
Run the code above in your browser using DataLab